@@ -144,6 +144,10 @@
 	"	namespace eval ::vfs { variable tclkit_version 1 }\n"
 	"	catch { uplevel #0 [list source [file join $mountpoint config.tcl]] }\n"
 	"\n"
+	"	# Set-up starkit::tclkitroot\n"
+	"	namespace eval ::starkit { variable tclkitroot }\n"
+	"	set ::starkit::tclkitroot $mountpoint\n"
+	"\n"
 	"	# Perform expected initialization\n"
 	"	uplevel #0 [list source [file join $tcl_library init.tcl]]\n"
 	"  \n"
@@ -163,19 +167,17 @@
 	"		if {[info exists ::TCLKIT_INITVFS] && [info exists ::tclKitFilename]} {\n"
 	"			catch {\n"
 	"				vfs::zip::Mount $::tclKitFilename \"/.KITDLL_USER\"\n"
-	"\n"
-	"				lappend auto_path \"/.KITDLL_USER/lib\"\n"
 	"			}\n"
 	"		}\n"
+	"		lappend auto_path \"/.KITDLL_USER/lib\"\n"
 	"\n"
 	"		## Mount the VFS from executable\n"
 	"		if {[info exists ::TCLKIT_INITVFS]} {\n"
 	"			catch {\n"
 	"				vfs::zip::Mount [info nameofexecutable] \"/.KITDLL_APP\"\n"
-	"\n"
-	"				lappend auto_path \"/.KITDLL_APP/lib\"\n"
 	"			}\n"
 	"		}\n"
+	"		lappend auto_path \"/.KITDLL_APP/lib\"\n"
 	"	}\n"
 	"\n"
 	"	# Clean up\n"
